/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.workflow.uad.anonymizer;

import com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.model.WorkflowDefinitionLink;
import com.liferay.portal.kernel.service.WorkflowDefinitionLinkLocalService;
import com.liferay.portal.workflow.uad.constants.PortalWorkflowUADConstants;

import com.liferay.user.associated.data.anonymizer.DynamicQueryUADAnonymizer;

import org.osgi.service.component.annotations.Reference;

/**
 * Provides the base implementation for the workflow definition link UAD anonymizer.
 *
 * <p>
 * This implementation exists only as a container for the default methods
 * generated by ServiceBuilder. All custom service methods should be put in
 * {@link WorkflowDefinitionLinkUADAnonymizer}.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @generated
 */
public abstract class BaseWorkflowDefinitionLinkUADAnonymizer
	extends DynamicQueryUADAnonymizer<WorkflowDefinitionLink> {
	@Override
	public void autoAnonymize(WorkflowDefinitionLink workflowDefinitionLink,
		long userId, User anonymousUser) throws PortalException {
		if (workflowDefinitionLink.getUserId() == userId) {
			workflowDefinitionLink.setUserId(anonymousUser.getUserId());
			workflowDefinitionLink.setUserName(anonymousUser.getFullName());
		}

		workflowDefinitionLinkLocalService.updateWorkflowDefinitionLink(workflowDefinitionLink);
	}

	@Override
	public void delete(WorkflowDefinitionLink workflowDefinitionLink)
		throws PortalException {
		workflowDefinitionLinkLocalService.deleteWorkflowDefinitionLink(workflowDefinitionLink);
	}

	@Override
	public Class<WorkflowDefinitionLink> getTypeClass() {
		return WorkflowDefinitionLink.class;
	}

	@Override
	protected ActionableDynamicQuery doGetActionableDynamicQuery() {
		return workflowDefinitionLinkLocalService.getActionableDynamicQuery();
	}

	@Override
	protected String[] doGetUserIdFieldNames() {
		return PortalWorkflowUADConstants.USER_ID_FIELD_NAMES_WORKFLOW_DEFINITION_LINK;
	}

	@Reference
	protected WorkflowDefinitionLinkLocalService workflowDefinitionLinkLocalService;
}